@@ -3,10 +3,7 @@ import Adafruit_PWM_Servo_Driver as servo_drv # Adafruit Industries 是纽约的
 import RPi.GPIO as GPIO
 import time
 import sys
-import servo
-import passive_buzzer as pbz
-import led
-import joystick
+from . import servo, led, joystick, passive_buzzer as pbz
 
 '''
 * Currently unused pins
